==> haskell-chell-quickcheck-0.2.5.4-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-CqxIlVXp0n8Die60sPtmA8
key:                  chell-quickcheck-0.2.5.4-CqxIlVXp0n8Die60sPtmA8
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  b650cc241f007b03f1c7ac17f43551f7
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-CqxIlVXp0n8Die60sPtmA8
depends:
    QuickCheck-2.15.0.1-CJDLs8WzPRbDbbjHGUhpIu base-4.17.2.1
    chell-0.5.0.2-Gt8JWv2QP3jIoEiKH8asT9
    random-1.2.1.3-2jtdg0FBSKzAasSf5KWDPe

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.4-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-2yk77O2jzQxnw7yPO0lsN
key:                  chell-quickcheck-0.2.5.4-2yk77O2jzQxnw7yPO0lsN
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  a0b32e5c2e234208fa666b2561ff9de7
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-2yk77O2jzQxnw7yPO0lsN
depends:
    QuickCheck-2.15.0.1-93Z9357UkgtKg8lpP8YyKm base-4.17.2.1
    chell-0.5.0.2-GBAyVtbs7os34eX5RwIKJ0
    random-1.2.1.3-1kyQGGmKWocERAlRbbTx7C

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
